<?php

namespace Tests\Feature;

use App\Models\User;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Str;
use Laravel\Passport\Passport;
use Tests\TestCase;

class XOSampleTest extends TestCase
{
    use RefreshDatabase;

    public function setUp(): void
    {
        parent::setUp();

        Artisan::call('passport:install');
    }

    public function testRegisterNoUsername()
    {
        $response = $this->postJson(
            '/api/register',
            [
                'email' => 'nima.user1@yahoo.com',
                'password' => 'user1user1'
            ]
        );

        $response->assertExactJson(['username' => ['The username field is required.']]);
    }

    public function testLoginNoUsernameNoPassword()
    {
        $response = $this->postJson(
            '/api/login',
            []
        );

        $response->assertExactJson(
            [
                'username' => ['The username field is required.'],
                'password' => ['The password field is required.']
            ]
        );
    }

    public function testGamesCreateSuccessful()
    {
        $user1 = User::factory()->create();
        $user2 = User::factory()->create();

        Passport::actingAs($user1);

        $response = $this->postJson(
            '/api/games/create',
            [
                'opponent' => $user2->username
            ]
        );

        $response->assertJson(
            [
                'id' => 1,
                'host_id' => $user1->id,
                'opponent_id' => $user2->id
            ]
        );
    }
}
